'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _item = require('../item');

var _item2 = _interopRequireDefault(_item);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class MaterializeGridifierItem extends _item2.default {
  constructor(props) {
    super(props);
    this.state.removeConfirm = false;
  }

  getClassNames() {
    const w = this.props.width;
    const h = this.props.height;
    return (0, _classnames2.default)('rg-grid-item col', `s${w * 4} m${w * 3} l${w * 2}`, `h${h}`);
  }

  getStyles() {
    if (this.props.backgroundColor) {
      return {
        'visibility': 'hidden',
        'backgroundColor': this.props.backgroundColor,
        'boxShadow': `1px 1px 0 ${this.props.backgroundColor}`
      };
    }
    return { 'visibility': 'hidden' };
  }

  getDimensions() {
    return `${this.props.width}:${this.props.height}`;
  }

  getWrapperClassNames() {
    const w = this.props.width;
    const h = this.props.height;
    return `rg-item-wrapper card w-fixer-${w} h-fixer-${h}`;
  }

  getDragHandler() {
    return _react2.default.createElement(
      'div',
      { className: 'rg-drag-handler rg-edition-tool' },
      _react2.default.createElement(
        'i',
        { className: 'material-icons' },
        'drag_handle'
      )
    );
  }

  getRemoveHandler() {
    return _react2.default.createElement(
      'div',
      { className: 'rg-remove-handler rg-edition-tool' },
      this.state.removeConfirm ? _react2.default.createElement(
        'div',
        { ref: 'removeConfirm', onClick: () => this.props.removeHandler(this),
          className: 'btn waves-effect waves-light red' },
        _react2.default.createElement(
          'i',
          { className: 'material-icons' },
          'delete_forever'
        )
      ) : _react2.default.createElement(
        'div',
        { ref: 'remove', onClick: () => this.removeConfirmation(), className: 'btn waves-effect waves-light orange' },
        _react2.default.createElement(
          'i',
          { className: 'material-icons' },
          'delete'
        )
      )
    );
  }

  removeConfirmation() {
    this.setState({ removeConfirm: true });
    this._removeConfirmationCanceler = setTimeout(() => {
      this.setState({ removeConfirm: false });
    }, 3000);
  }

  componentWillUnmount() {
    if (this._removeConfirmationCanceler) {
      clearTimeout(this._removeConfirmationCanceler);
    }
  }

  getMoreHandlers() {
    const resize = this.props.resizeHandler ? _react2.default.createElement(
      'div',
      { onClick: event => this.props.resizeHandler(this, event), className: 'btn waves-effect waves-light' },
      _react2.default.createElement(
        'i',
        { className: 'material-icons' },
        'photo_size_select_small'
      )
    ) : null;
    const settings = this.props.settingsHandler ? _react2.default.createElement(
      'div',
      { onClick: event => this.props.settingsHandler(this, event), className: 'btn waves-effect waves-light' },
      _react2.default.createElement(
        'i',
        { className: 'material-icons' },
        'settings'
      )
    ) : null;
    return settings || resize ? _react2.default.createElement(
      'div',
      { className: 'rg-settings-handler rg-edition-tool' },
      resize,
      ' ',
      settings
    ) : null;
  }
}

MaterializeGridifierItem.propTypes = {
  width: _propTypes2.default.oneOf([1, 2, 3]),
  height: _propTypes2.default.oneOf([1, 2, 3, 4, 5]),
  backgroundColor: _propTypes2.default.string,
  settingsHandler: _propTypes2.default.func,
  resizeHandler: _propTypes2.default.func
};

MaterializeGridifierItem.defaultProps = {
  width: 1,
  height: 1
};

exports.default = MaterializeGridifierItem;